@@ -1,5 +1,6 @@
 from gitlabber.naming import FolderNaming
 import pytest
+import re
 
 def test_naming_parse():
     assert FolderNaming.PATH == FolderNaming.argparse("PATH")
@@ -7,6 +8,9 @@ def test_naming_parse():
 def test_naming_string():
     assert "name" == FolderNaming.__str__(FolderNaming.NAME)
 
+def test_repr():
+    retval = repr(FolderNaming.PATH)
+    match = re.match("^<FolderNaming: ({.*})>$", retval)
 
 def test_naming_invalid():
     assert "invalid_value" == FolderNaming.argparse("invalid_value")
